==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/ja-JP/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'このユーザはログインすることができます。',
    'activated_disabled_help_text' => '自分自身のアカウント有効化状態は編集できません。',
    'assets_user'       => ':name に資産を割り当てる',
    'bulk_update_warn'	=> ': user_count 人のプロパティを編集しようとしています。このフォームを使用してユーザー属性を変更することはできません。ユーザー個別に編集をする必要があります。',
    'bulk_update_help'	=> 'このフォームは一度に複数利用者を更新することが可能です。変更が必要なフィールドにのみ入力をして下さい。空白のフィールドは変更されません。',
    'current_assets'    => '資産をこのユーザーにチェック アウト',
    'clone'             => '利用者を複製',
    'contact_user'      => ':name にコンタクト',
    'edit'              => '利用者を編集',
    'filetype_info'     => '許可するファイルタイプ（png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, and rar）',
    'history_user'      => ':nameの履歴',
    'info'				=> '情報',
    'restore_user'		=> '復元するには、ここをクリックします。',
    'last_login'        => '最終ログイン',
    'ldap_config_text'  => 'LDAP 構成設定 管理者 > 設定。 選択した場所は、インポートされたすべてのユーザーに対して設定されます。',
    'print_assigned'    => '割り当て先をすべて印刷',
    'email_assigned'    => '割り当てられたすべてのメール一覧',
    'user_notified'     => 'ユーザーは現在割り当てられているアイテムのリストを電子メールで送信しました。',
    'auto_assign_label' => '該当するライセンスを自動で割り当てる場合の、このユーザーを含める',
    'auto_assign_help'  => 'このユーザーのライセンスの自動割り当てをスキップ',
    'software_user'     => 'ソフトウェアは :name にチェックアウトしました。',
    'send_email_help'   => '資格情報を送信するには、このユーザーのメールアドレスを入力する必要があります。メール送信資格情報は、ユーザー作成時にのみ行うことができます。 パスワードは一方向のハッシュに保存され、保存されると取得できません。',
    'view_user'         => '利用者 :name を表示',
    'usercsv'           => 'CSVファイル',
    'two_factor_admin_optin_help' => '現在の管理者設定では、2段階認証は任意です。  ',
    'two_factor_enrolled' => '2要素認証デバイスが登録されました ',
    'two_factor_active'   => '2要素認証有効 ',
    'user_deactivated'  => 'ユーザーはログインできません',
    'user_activated'  => 'ユーザーはログインできます',
    'activation_status_warning' => 'アクティベーション状態を変更しない',
    'group_memberships_helpblock' => 'スーパー管理者のみがグループメンバーシップを編集できます。',
    'superadmin_permission_warning' => 'スーパー管理者のみがユーザーにスーパー管理者権限を付与できます。',
    'admin_permission_warning' => '管理者権限以上のユーザーのみがユーザーの管理者権限を付与できます。',
    'remove_group_memberships' => 'グループメンバーシップを削除',
    'warning_deletion_information' => '以下の :count ユーザーからのすべてのアイテムをチェックインしようとしています。スーパー管理者名は赤でハイライトされます。',
    'update_user_assets_status' => 'これらのユーザーのすべてのアセットをこのステータスに更新します',
    'checkin_user_properties' => 'これらのユーザーに関連付けられているすべてのプロパティをチェック',
    'remote_label'   => 'これはリモートのユーザーです',
    'remote'   => 'リモート',
    'remote_help' => 'これは、物理的な場所に来たことがない、またはほとんど来なかったリモートユーザーによってフィルタリングする必要がある場合に便利です。',
    'not_remote_label' => 'これはリモートユーザーではありません',
    'vip_label' => 'VIP ユーザー',
    'vip_help' => 'これは、組織内の重要な人物を特別な方法で扱いたい場合に役立ちます。',
    'create_user' => 'ユーザーを作成',
    'create_user_page_explanation' => '初めてサイトにアクセスする際に使用するアカウント情報です。',
    'email_credentials' => '電子メールの資格情報',
    'email_credentials_text' => '上記のメールアドレスに自分の資格情報を送信',
    'next_save_user' => '次へ: ユーザの保存',
    'all_assigned_list_generation' => '生成日時：',
    'email_user_creds_on_create' => 'このユーザーの資格情報を電子メールで送信しますか？',
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/ja-JP/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'このユーザはログインすることができます。',
    'activated_disabled_help_text' => '自分自身のアカウント有効化状態は編集できません。',
    'assets_user'       => ':name に資産を割り当てる',
    'bulk_update_warn'	=> ': user_count 人のプロパティを編集しようとしています。このフォームを使用してユーザー属性を変更することはできません。ユーザー個別に編集をする必要があります。',
    'bulk_update_help'	=> 'このフォームは一度に複数利用者を更新することが可能です。変更が必要なフィールドにのみ入力をして下さい。空白のフィールドは変更されません。',
    'current_assets'    => '資産をこのユーザーにチェック アウト',
    'clone'             => '利用者を複製',
    'contact_user'      => ':name にコンタクト',
    'edit'              => '利用者を編集',
    'filetype_info'     => '許可するファイルタイプ（png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, and rar）',
    'history_user'      => ':nameの履歴',
    'info'				=> '情報',
    'restore_user'		=> '復元するには、ここをクリックします。',
    'last_login'        => '最終ログイン',
    'ldap_config_text'  => 'LDAP 構成設定 管理者 > 設定。 選択した場所は、インポートされたすべてのユーザーに対して設定されます。',
    'print_assigned'    => '割り当て先をすべて印刷',
    'email_assigned'    => '割り当てられたすべてのメール一覧',
    'user_notified'     => 'ユーザーは現在割り当てられているアイテムのリストを電子メールで送信しました。',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => '該当するライセンスを自動で割り当てる場合の、このユーザーを含める',
    'auto_assign_help'  => 'このユーザーのライセンスの自動割り当てをスキップ',
    'software_user'     => 'ソフトウェアは :name にチェックアウトしました。',
    'send_email_help'   => '資格情報を送信するには、このユーザーのメールアドレスを入力する必要があります。メール送信資格情報は、ユーザー作成時にのみ行うことができます。 パスワードは一方向のハッシュに保存され、保存されると取得できません。',
    'view_user'         => '利用者 :name を表示',
    'usercsv'           => 'CSVファイル',
    'two_factor_admin_optin_help' => '現在の管理者設定では、2段階認証は任意です。  ',
    'two_factor_enrolled' => '2要素認証デバイスが登録されました ',
    'two_factor_active'   => '2要素認証有効 ',
    'user_deactivated'  => 'ユーザーはログインできません',
    'user_activated'  => 'ユーザーはログインできます',
    'activation_status_warning' => 'アクティベーション状態を変更しない',
    'group_memberships_helpblock' => 'スーパー管理者のみがグループメンバーシップを編集できます。',
    'superadmin_permission_warning' => 'スーパー管理者のみがユーザーにスーパー管理者権限を付与できます。',
    'admin_permission_warning' => '管理者権限以上のユーザーのみがユーザーの管理者権限を付与できます。',
    'remove_group_memberships' => 'グループメンバーシップを削除',
    'warning_deletion_information' => '以下の :count ユーザーからのすべてのアイテムをチェックインしようとしています。スーパー管理者名は赤でハイライトされます。',
    'update_user_assets_status' => 'これらのユーザーのすべてのアセットをこのステータスに更新します',
    'checkin_user_properties' => 'これらのユーザーに関連付けられているすべてのプロパティをチェック',
    'remote_label'   => 'これはリモートのユーザーです',
    'remote'   => 'リモート',
    'remote_help' => 'これは、物理的な場所に来たことがない、またはほとんど来なかったリモートユーザーによってフィルタリングする必要がある場合に便利です。',
    'not_remote_label' => 'これはリモートユーザーではありません',
    'vip_label' => 'VIP ユーザー',
    'vip_help' => 'これは、組織内の重要な人物を特別な方法で扱いたい場合に役立ちます。',
    'create_user' => 'ユーザーを作成',
    'create_user_page_explanation' => '初めてサイトにアクセスする際に使用するアカウント情報です。',
    'email_credentials' => '電子メールの資格情報',
    'email_credentials_text' => '上記のメールアドレスに自分の資格情報を送信',
    'next_save_user' => '次へ: ユーザの保存',
    'all_assigned_list_generation' => '生成日時：',
    'email_user_creds_on_create' => 'このユーザーの資格情報を電子メールで送信しますか？',
];
